@@ -3,9 +3,9 @@ package AppleII::Disk;
 #
 # Copyright 1996-2006 Christopher J. Madsen
 #
-# Author: Christopher J. Madsen <cjm@pobox.com>
+# Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created: 25 Jul 1996
-# $Id: Disk.pm 1317 2006-03-29 02:43:10Z cjm $
+# $Id: Disk.pm 1719 2007-03-24 17:35:39Z cjm $
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -31,7 +31,7 @@ use bytes;
 
 BEGIN
 {
-  $VERSION = '0.06';
+  $VERSION = '0.08';
 } # end BEGIN
 
 #=====================================================================
@@ -538,6 +538,12 @@ Reads one sector from the disk image.  C<$track> is the track number,
 and C<$sector> is the DOS 3.3 logical sector number.  This is
 currently implemented only for DOS 3.3 order images.
 
+=item $disk->fully_allocate()
+
+Expands the the physical size of the disk image file to match the
+logical size of the disk image.  It will be expanded as a sparse file
+if the filesystem containing the image file supports sparse files.
+
 =item $disk->write_block($block, $contents, [$pad])
 
 Writes one block to the disk image.  C<$block> is the block number to
@@ -587,10 +593,40 @@ C<write_XXX> methods will call it for you.
 
 =head1 AUTHOR
 
-Christopher J. Madsen E<lt>F<cjm@pobox.com>E<gt>
+Christopher J. Madsen C<< <perl AT cjmweb.net> >>
+
+Please report any bugs or feature requests to
+C<< <bug-LibA2 AT rt.cpan.org> >>, or through the web interface
+at L<http://rt.cpan.org/Public/Bug/Report.html?Queue=LibA2>
+
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
-
-# Local Variables:
-# tmtrack-file-task: "AppleII::Disk.pm"
-# End:
